# -*- coding: utf-8 -*-
import sys, os, pkginfo, datetime

pkg_info = pkginfo.Develop(os.path.join(os.path.dirname(__file__),'..'))

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx'
    ]

intersphinx_mapping = {'http://docs.python.org/dev': None}

# General
source_suffix = '.txt'
source_encoding = 'latin-1'
master_doc = 'index'
project = pkg_info.name
copyright = '2008-%s Simplistix Ltd' % datetime.datetime.now().year
version = release = pkg_info.version
exclude_trees = ['_build']
unused_docs = ['description']
pygments_style = 'sphinx'

# Options for HTML output
html_theme = 'default'
htmlhelp_basename = project+'doc'

# Options for LaTeX output
latex_documents = [
  ('index',project+'.tex', project+u' Documentation',
   'Simplistix Ltd', 'manual'),
]




# Copyright (c) 2005-2006 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

import os
from AccessControl.SecurityManagement import newSecurityManager
from AccessControl.SecurityManagement import noSecurityManager
from AccessControl.User import system as SystemUser,SimpleUser
from cStringIO import StringIO
from OFS.Folder import Folder
from Products.MailHost.MailHost import MailHost
from test_MailTemplate import DummyMailHost,Zope,get_transaction
from Testing.makerequest import makerequest
from unittest import TestCase,TestSuite,makeSuite,main

try:
    import Products.CMFCore
except ImportError:
    # no CMF, no use ;-)
    class TestFSMailTemplate(TestCase):
        pass
else:
    from Products.CMFCore.DirectoryView import addDirectoryViews
    from Products.CMFCore.tests.base.testcase import FSDVTest
    from Products.CMFCore.tests.base.dummy import DummyFolder
    from AccessControl import ClassSecurityInfo
    from Globals import InitializeClass
    
    class DummyMember:

        security = ClassSecurityInfo()
        
        security.declareObjectPublic()
        security.setDefaultAccess('allow')

        security.declarePublic('getUserName')
        def getUserName(self):
            return 'Test Member'

        security.declarePublic('getProperty')
        def getProperty(self,name):
            return 'member@example.com'

    InitializeClass(DummyMember)
    
    class DummyMembershipTool:

        security = ClassSecurityInfo()

        security.declareObjectPublic()
        security.setDefaultAccess('allow')

        security.declarePublic('listMembers')
        def listMembers(self):
            return (DummyMember(),)

    InitializeClass(DummyMembershipTool)
    
    class TestFSMailTemplate(FSDVTest):
        
        _sourceprefix = os.path.dirname(__file__)

        def setUp(self):
            FSDVTest.setUp(self)
            self.app = makerequest(Zope.app())
            self._registerDirectory()
            ob = self.ob = self.app
            addDirectoryViews(ob, self._skinname, self.tempname)
            self.r = self.app.REQUEST
            self.r.other['URL1'] = 'http://foo/test_mt'
            self._add= self.app.manage_addProduct['MailTemplates'].addMailTemplate
            self.folder = Folder('folder')
            if getattr(self.app,'test_mt',None):
                self.app.manage_delObjects(ids=['test_mt'])
            if getattr(self.app,'MailHost',None):
                self.app.manage_delObjects(ids=['MailHost'])
            self.MailHost = self.app.MailHost = DummyMailHost()
            newSecurityManager( None, SystemUser )
        
        def tearDown(self):
            noSecurityManager()
            get_transaction().abort()
            self.app._p_jar.close()
            try:
                FSDVTest.tearDown(self)
            except OSError:
                # waggh, on windows, files in .svn get locked for some reason :-(
                pass


        def test_render(self):
            self.MailHost.setExpected(mfrom='from@example.com',
                                      mto=('to@example.com','to2@example.com'),
                                      filename='mail_FSSendSimple.txt')

            self.ob.fake_skin.test.send(subject=self.ob.fake_skin.test.subject % 'out',
                                        mcc=('cc@example.com',),
                                        mbcc=('bcc@example.com',),
                                        headers={
                'To':('to@example.com','to2@example.com'),
                'Subject':'cheese',
                })

            self.MailHost.checkSent()
        
            # check we're not setting a content type
            self.failIf(self.r.RESPONSE.headers.get('content-type'),
                        self.r.RESPONSE.headers)

        def test_properties(self):
            self.assertEqual(self.ob.fake_skin.test.mailhost,'MailHost')
            self.assertEqual(self.ob.fake_skin.test.subject,'Hello %s there')
            self.assertEqual(self.ob.fake_skin.test.mfrom,'from@example.com')
            
        def test_zodbclone(self):
            from Products.MailTemplates.MailTemplate import MailTemplate
            clone = self.ob.fake_skin.test._createZODBClone()
            self.failUnless(isinstance(clone,MailTemplate),'Clone not a MailTemplate!')
            self.assertEqual(self.ob.fake_skin.test.read(),clone.read())
            self.assertEqual(clone.getProperty('mailhost'),None)
            self.assertEqual(clone.mailhost,'MailHost')
            self.assertEqual(clone.getProperty('subject'),'Hello %s there')
            self.assertEqual(clone.getProperty('mfrom'),'from@example.com')
            self.assertEqual(clone.content_type,'text/notplain')
            
        def test_view_manage_workspace(self):
            from zExceptions import Redirect
            try:
                self.assertRaises(self.ob.fake_skin.test.manage_workspace(self.r))
            except Redirect,r:
                # this may appear to be incorrect, but http://foo/test_mt
                # is what we set as REQUEST['URL1']
                self.assertEqual(r.args,('http://foo/test_mt/manage_main',))
            self.ob.fake_skin.test.manage_main()
            # ugh, okay, so we can't really test for security, but lets
            # test for the missing docstring that was causing problems!
            self.failUnless(self.ob.fake_skin.test.__doc__)
            
        def test_example2(self):
            # login
            noSecurityManager()
            self.app.aq_chain[-1].id = 'testing'
            newSecurityManager(
                None,
                SimpleUser('Test User','',('Manager',),[]).__of__(self.app)
                )
            try:
                # setup
                self.app.portal_membership = DummyMembershipTool()
                # set expected
                self.MailHost.setExpected(mfrom='webmaster@example.com',
                                          mto='member@example.com',
                                          filename='example2.txt')
                # test
                self.ob.fake_skin.send_mails()
            finally:
                # logout
                noSecurityManager()
                newSecurityManager( None, SystemUser )

def test_suite():
    return TestSuite((
        makeSuite(TestFSMailTemplate),
        ))

if __name__ == '__main__':
    main(defaultTest='test_suite')




# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

import os
import rfc822

from AccessControl import ClassSecurityInfo
from DateTime import DateTime
from email.MIMEMultipart import MIMEMultipart
from email.MIMEText import MIMEText

from App.class_init import InitializeClass
from App.Common import package_home
from MTMultipart import MTMultipart
from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
from Products.PageTemplates.PageTemplateFile import PageTemplateFile

from ZPublisher import HTTPResponse

# Configured using zope.conf in Zope 2.7.8, Zope 2.8.2, and above
default_encoding = getattr(HTTPResponse,'default_encoding','iso-8859-15')

class BaseMailTemplate:

    security = ClassSecurityInfo()

    _properties = ()
    
    ZScriptHTML_tryForm = None

    mailhost = None
    
    security.declarePrivate('_process')
    def _process(self,kw):
        # sort out what encoding we're going to use
        encoding = kw.get('encoding',
                          self.getProperty('encoding',
                                           default_encoding))
        # decode all kw
        unicode_kw = {}
        for k,v in kw.items():
            if isinstance(v,str):
                v = v.decode(encoding)
            unicode_kw[k]=v
        text = self.__class__.__bases__[1].__call__(self,**unicode_kw)
        
        # now turn the result into a MIMEText object
        msg = MIMEText(
            text.replace('\r','').encode(encoding),
            self.content_type.split('/')[1],
            encoding
            )
        # sort out what headers and addresses we're going to use
        headers = {}
        values = {}
        # headers from the headers property
        for header in getattr(self,'headers',()):
            name,value = header.split(':',1)
            headers[name]=value
        # headers from the headers parameter
        headers_param = kw.get('headers',{})
        headers.update(headers_param)
        # values and some specific headers
        for key,header in (('mfrom','From'),
                           ('mto','To'),
                           ('mcc','Cc'),
                           ('mbcc','Bcc'),
                           ('subject','Subject')):
            value = kw.get(key,
                           headers_param.get(header,
                                             getattr(self,
                                                     key,
                                                     headers.get(header))))
            if value is not None:
                values[key]=value
                # turn some sequences in coma-seperated strings
                if isinstance(value,tuple) or isinstance(value,list):
                    value = ', '.join(value)
                # make sure we have no unicode headers
                if isinstance(value,unicode):
                    value = value.encode(encoding)
                headers[header]=value
        # check required values have been supplied
        errors = []
        for param in ('mfrom','mto','subject'):
            if not values.get(param):
                errors.append(param)
        if errors:
            raise TypeError(
                'The following parameters were required by not specified: '+(
                ', '.join(errors)
                ))
        # add date header
        headers['Date']=DateTime().rfc822()
        # turn headers into an ordered list for predictable header order
        keys = headers.keys()
        keys.sort()
        return msg,values,[(key,headers[key]) for key in keys]
        
    security.declarePrivate('_send')
    def _send(self,mfrom,mto,msg):
            
        mailhost = self.restrictedTraverse(self.mailhost,None)
        if not getattr(mailhost,'meta_type',None) in (
            'Mail Host','Maildrop Host'
            ):
            raise RuntimeError(
                'Could not traverse to MailHost %r' % self.mailhost
                )
        
        mailhost._send(mfrom,mto,msg.as_string())

    security.declareProtected('View', 'send')
    def send(self,**kw):

        msg,values,headers = self._process(kw)

        for header,value in headers:
            msg[header]=value

        to_addrs = ()
        for key in ('mto', 'mcc', 'mbcc'):
            v = values.get(key)
            if v:
                if isinstance(v, basestring):
                    v = [rfc822.dump_address_pair(addr) for addr \
                            in rfc822.AddressList(v)]
                to_addrs += tuple(v)
        
        self._send(values['mfrom'], to_addrs, msg)

    security.declareProtected('View', '__call__')
    __call__ = send

    security.declareProtected('View', 'as_message')
    def as_message(self,**kw):

        msg,values,headers = self._process(kw)

        multipart_kw = {}
        subtype = kw.get('subtype')
        if subtype:
            multipart_kw['_subtype'] = subtype
        boundary = kw.get('boundary')
        if boundary:
            multipart_kw['boundary'] = boundary
            
        multipart = MTMultipart(self,
                                values['mfrom'],
                                values['mto'],
                                **multipart_kw)

        # set the encoding for the container
        multipart.set_charset(msg.get_charset())
        
        for header,value in headers:
            multipart[header]=value
            
        multipart.attach(msg)

        return multipart
        
InitializeClass(BaseMailTemplate)

    



# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

import os

from AccessControl import ClassSecurityInfo
from AccessControl import getSecurityManager
from App.class_init import InitializeClass
from App.Common import package_home
from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
from Products.PageTemplates.ZopePageTemplate import charsetFromMetaEquiv
from Products.PageTemplates.ZopePageTemplate import encodingFromXMLPreamble
from Products.PageTemplates.ZopePageTemplate import convertToUnicode
from Products.PageTemplates.ZopePageTemplate import preferred_encodings
from Products.PageTemplates.ZopePageTemplate import PageTemplate

from Products.PageTemplates.PageTemplateFile import PageTemplateFile

from BaseMailTemplate import BaseMailTemplate

class MailTemplate(BaseMailTemplate,ZopePageTemplate):
    "A ZPT-like template for sending mails"
    
    security = ClassSecurityInfo()

    meta_type = 'Mail Template'

    _properties = ()
    
    manage_options = ZopePageTemplate.manage_options[0:1] + \
                     ZopePageTemplate.manage_options[2:]

    _default_content_fn = os.path.join(package_home(globals()),
                                       'www', 'default.txt')

    def __init__(self,*args,**kw):
        ZopePageTemplate.__init__(self,*args,**kw)
        self.content_type = 'text/plain'
        
    def pt_edit(self, text, content_type, keep_output_encoding=False):

        text = text.strip()
        
        is_unicode = isinstance(text, unicode)
        encoding = None
        output_encoding = None

        if content_type.startswith('text/xml'):

            if is_unicode:
                encoding = None
                output_encoding = 'utf-8'
            else:
                encoding = encodingFromXMLPreamble(text)
                output_encoding = 'utf-8'

        elif content_type.startswith('text/html'):

            charset = charsetFromMetaEquiv(text)

            if is_unicode:
                if charset:
                    encoding = None
                    output_encoding = charset
                else:
                    encoding = None
                    output_encoding = 'iso-8859-15'
            else:
                if charset:
                    encoding = charset
                    output_encoding = charset
                else:
                    encoding = 'iso-8859-15'
                    output_encoding = 'iso-8859-15'

        elif is_unicode:
            utext = text
            output_encoding = 'utf-8'
        else:
            utext, encoding = convertToUnicode(text,
                                               content_type,
                                               preferred_encodings)
            output_encoding = encoding

        # for content updated through WebDAV, FTP 
        if not keep_output_encoding:
            self.output_encoding = output_encoding

        if not is_unicode:
            text = unicode(text, encoding)

        self.ZCacheable_invalidate()
        PageTemplate.pt_edit(self, text, content_type)
        
    security.declareProtected('View management screens','pt_editForm')
    pt_editForm = PageTemplateFile('www/mtEdit', globals(),
                                   __name__='pt_editForm')
    manage = manage_main = pt_editForm

    security.declareProtected('Change Page Templates','pt_editAction')
    def pt_editAction(self, REQUEST, mailhost, text, content_type, expand):
        """Change the mailhost and document."""
        if self.wl_isLocked():
            raise ResourceLockedError, "File is locked via WebDAV"
        self.expand=expand
        self._setPropValue('mailhost',mailhost)
        REQUEST.set('text', self.read()) # May not equal 'text'!
        text = unicode(text, 'utf-8')

        self.pt_edit(text, content_type, True)
        REQUEST.set('text', self.read()) # May not equal 'text'!
        message = "Saved changes."
        if getattr(self, '_v_warnings', None):
            message = ("<strong>Warning:</strong> <i>%s</i>"
                       % '<br>'.join(self._v_warnings))
        return self.pt_editForm(manage_tabs_message=message)

    def om_icons(self):
        """Return a list of icon URLs to be displayed by an ObjectManager"""
        icons = ({'path': 'misc_/MailTemplates/mt.gif',
                  'alt': self.meta_type, 'title': self.meta_type},)
        if not self._v_cooked:
            self._cook()
        if self._v_errors:
            icons = icons + ({'path': 'misc_/PageTemplates/exclamation.gif',
                              'alt': 'Error',
                              'title': 'This template has an error'},)
        return icons

    def _exec(self, bound_names, args, kw):
        """Call a Page Template"""
        if not kw.has_key('args'):
            kw['args'] = args
        bound_names['options'] = kw

        security=getSecurityManager()
        bound_names['user'] = security.getUser()

        # Retrieve the value from the cache.
        keyset = None
        if self.ZCacheable_isCachingEnabled():
            # Prepare a cache key.
            keyset = {'here': self._getContext(),
                      'bound_names': bound_names}
            result = self.ZCacheable_get(keywords=keyset)
            if result is not None:
                # Got a cached value.
                return result

        # Execute the template in a new security context.
        security.addContext(self)
        try:
            result = self.pt_render(extra_context=bound_names)
            if keyset is not None:
                # Store the result in the cache.
                self.ZCacheable_set(result, keywords=keyset)
            return result
        finally:
            security.removeContext(self)

InitializeClass(MailTemplate)

    



# -*- coding: latin-1 -*-
# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.
import os

import Zope2 as Zope

from AccessControl.SecurityManagement import newSecurityManager
from AccessControl.SecurityManagement import noSecurityManager
from AccessControl.User import system as SystemUser, SimpleUser
from cStringIO import StringIO
from difflib import unified_diff
from email import message_from_string
from OFS.Folder import Folder
from Products.MailHost.MailHost import MailHost
from Testing.makerequest import makerequest
from unittest import TestCase,TestSuite,makeSuite,main

from transaction import get as get_transaction

test_folder = os.path.dirname(__file__)

class DummyFieldStorage:
    def __init__(self,filename,value):
        self.filename = filename
        self.value = value
        self.file = StringIO(value)
        self.content_type = None
        self.headers = {}

class DummyMailHost(MailHost):

    sent = False
    
    def setExpected(self,mfrom,mto,filename,payload=None):
        self.mfrom = mfrom
        self.mto = mto
        self.messageText = open(
            os.path.join(test_folder,filename)
            ).read().replace('\r','')
        self.filename = filename
        self.payload = payload

    def getId(self):
        return 'MailHost'

    def title_and_id(self):
        return 'MHTID'
    
    def assertEqual(self,x,y,message=None,field=None):
        if x!=y:
            if message:
                raise AssertionError(message)
            error = '%r!=%r' % (x,y)
            if field:
                error = field+':'+error
            raise AssertionError(error)
        
        
    def _send(self,mfrom,mto,messageText):
        self.assertEqual(self.mfrom,mfrom,field='mfrom')
        self.assertEqual(self.mto,mto,field='mto')
        expected_data = self.messageText.strip().split('\n')
        if self.payload:
            msg = message_from_string(messageText)
            self.assertEqual(
                self.payload,
                msg.get_payload(decode=True).decode(
                    msg.get_content_charset()
                    ))
        actual_data = messageText.strip().split('\n')
        # ignore dates
        for i in range(len(actual_data)):
            if actual_data[i].startswith('Date:'):
                actual_data[i]='Date:'
        diff = tuple(unified_diff(
            expected_data,
            actual_data,
            self.filename,
            'Test results',
            ))
        if diff:
            # import pdb; pdb.set_trace()
            raise AssertionError(
                'Mail sent was not as expected:\n\n'+'\n'.join(diff)
                )

        self.sent = True

    def checkSent(self,value=True):
        if value:
            error = "Mail not sent"
        else:
            error = "Mail sent when it shouldn't have been"
        self.assertEqual(self.sent,value,error)
        
class DummyMailDropHost(DummyMailHost):

    meta_type = 'Maildrop Host'
    
class TestMailTemplate(TestCase):

    def setUp(self):
        self.app = makerequest(Zope.app())
        self.r = self.app.REQUEST
        self.r.other['URL1'] = 'http://foo/test_mt'
        self._add= self.app.manage_addProduct['MailTemplates'].addMailTemplate
        if getattr(self.app,'test_mt',None):
            self.app.manage_delObjects(ids=['test_mt'])
        if getattr(self.app,'MailHost',None):
            self.app.manage_delObjects(ids=['MailHost'])
        self.MailHost = self.app.MailHost = DummyMailHost()
        o = list(self.app._objects)
        o.append({'meta_type': 'Mail Host', 'id': 'MailHost'})
        self.app._objects = tuple(o)
        newSecurityManager( None, SystemUser )
        
    def tearDown(self):
        noSecurityManager()
        get_transaction().abort()
        self.app._p_jar.close()

    def makeFileUpload(self,filename='test.txt',value='test text',
                       diskname=''):
        if diskname:
            filename = diskname
            value = open(
                os.path.join(test_folder,diskname)
                ).read().replace('\r','').strip()
        from ZPublisher.HTTPRequest import FileUpload
        return FileUpload(DummyFieldStorage(
            filename,
            value
            ))
    
    def checkContent(self,text='test text'):
        if text is None:
            text = open(os.path.join(test_folder,'..','www','default.txt')).read()            
        self.assertEqual(
            self.app.test_mt.document_src({'raw':1}),
            text
            )
        
    # Test Adding
    
    def test_addAddForm(self):
        self.app.manage_addProduct['MailTemplates'].addMailTemplateForm()

    def test_addAddFormNoMailHosts(self):
        self.app.manage_delObjects(ids=['MailHost'])
        res = self.app.manage_addProduct['MailTemplates'].addMailTemplateForm()
        self.failUnless(
            res.find(
            '<option value="MailHost">MHTID</option>'
            )==-1
            )

    def test_addAddFormMailHost(self):
        self.app._objects = ({'meta_type': 'Mail Host', 'id': 'MailHost'},)
        res = self.app.manage_addProduct['MailTemplates'].addMailTemplateForm()
        self.failIf(
            res.find(
            '<option value="MailHost">MHTID</option>'
            )==-1
            )

    def test_addAddFormMailDropHost(self):
        if getattr(self.app,'MailHost',None):
            self.app.manage_delObjects(ids=['MailHost'])
        self.MailHost = self.app.MailHost = DummyMailDropHost()
        self.app._objects = ({'meta_type': 'Maildrop Host', 'id': 'MailHost'},)
        res = self.app.manage_addProduct['MailTemplates'].addMailTemplateForm()
        self.failIf(
            res.find(
            '<option value="MailHost">MHTID</option>'
            )==-1
            )

    def test_addNoREQUEST(self):
        self._add('test_mt','MailHost')        
        # check settings
        self.assertEqual(self.app.test_mt.expand,0)
        self.assertEqual(self.app.test_mt.mailhost,'MailHost')
        self.assertEqual(self.app.test_mt.content_type,'text/plain')
        # check default content
        self.checkContent(None)

    def test_addNoMailHostSelected(self):
        self._add('test_mt',REQUEST=self.r)        
        # check settings
        self.assertEqual(self.app.test_mt.expand,0)
        self.assertEqual(self.app.test_mt.mailhost,None)
        self.assertEqual(self.app.test_mt.content_type,'text/plain')
        # check default content
        self.checkContent(None)
        # check the error we get when we try to send
        self.assertRaises(
            RuntimeError,self.app.test_mt,
            mfrom='from@example.com',
            mto='to@example.com',
            subject='Test Subject',
            )
        # no put a mogus mailhost in and check we get the same error
        self.app.test_mt.mailhost='bogus'
        self.assertRaises(
            RuntimeError,self.app.test_mt,
            mfrom='from@example.com',
            mto='to@example.com',
            subject='Test Subject',
            )

    def test_add(self,body = None):
        text = open(os.path.join(test_folder,'..','www','default.txt')).read()
        if body is not None:
            text = text[:-13] + body + text[-13:]
            self._add('test_mt','MailHost',text=text,REQUEST=self.r)
        else:
            self._add('test_mt','MailHost',REQUEST=self.r)
            
        self.assertEqual(
            self.r.RESPONSE.headers,
            {'status': '302 Moved Temporarily', 'location': 'http://foo/manage_main'}
            )
        self.mt = self.app.test_mt
        # check settings
        self.assertEqual(self.mt.expand,0)
        self.assertEqual(self.mt.mailhost,'MailHost')
        self.assertEqual(self.mt.content_type,'text/plain')
        # check default content
        self.assertEqual(
            self.app.test_mt.read(),
            text
            )
        # check default content type is text/plain
        self.assertEqual(self.app.test_mt.content_type,'text/plain')

    def test_addFile(self):
        self.r.form['file'] = self.makeFileUpload()
        self._add('test_mt','MailHost',REQUEST=self.r)
        # check settings
        self.assertEqual(self.app.test_mt.expand,0)
        self.assertEqual(self.app.test_mt.mailhost,'MailHost')
        self.assertEqual(self.app.test_mt.content_type,'text/plain')
        # check default content
        self.checkContent()

    def test_addEdit(self):
        self._add('test_mt','MailHost',REQUEST=self.r,submit=' Add and Edit ')
        self.assertEqual(
            self.r.RESPONSE.headers,
            {'status': '302 Moved Temporarily', 'location': 'http://foo/test_mt/manage_main'}
            )
        # check settings
        self.assertEqual(self.app.test_mt.expand,0)
        self.assertEqual(self.app.test_mt.mailhost,'MailHost')
        self.assertEqual(self.app.test_mt.content_type,'text/plain')
        # check default content
        self.checkContent(None)
        
    def test_addEditFile(self):
        self.r.form['file'] = self.makeFileUpload()
        self._add('test_mt','MailHost',REQUEST=self.r,submit=' Add and Edit ')
        self.assertEqual(
            self.r.RESPONSE.headers,
            {'status': '302 Moved Temporarily', 'location': 'http://foo/test_mt/manage_main'}
            )
        # check settings
        self.assertEqual(self.app.test_mt.expand,0)
        self.assertEqual(self.app.test_mt.mailhost,'MailHost')
        self.assertEqual(self.app.test_mt.content_type,'text/plain')
        # check default content
        self.checkContent()

    # Test Properties Tab
    # Not much here, as we assume PropertyManager does its job ;-)
    
    def test_PropertiesForm(self):
        self.test_add()
        self.mt.manage_propertiesForm()

    def test_PropertiesStartsEmpty(self):
        self.test_add()
        self.failIf(self.mt.propertyMap())

    # Test Test tab, well, actually, make sure it's not there ;-)
    
    def test_NoTestTab(self):
        from Products.MailTemplates.MailTemplate import MailTemplate
        for option in MailTemplate.manage_options:
            if option['label']=='Test':
                self.fail('Test label found')
        self.failIf(MailTemplate.ZScriptHTML_tryForm, 'try form not None')

    # Test Editing

    def test_editForm(self):
        self.test_add()
        self.mt.pt_editForm()

    def test_editFormMailHostGone(self):
        self.test_add()
        self.app.manage_delObjects('MailHost')
        r = self.mt.pt_editForm()
        self.failIf(
            r.find(
            """<option selected="selected" value="MailHost">'MailHost' is no longer valid!</option>"""
            )==-1,'No warning for MailHost being invalid found in:\n'+r
            )

    def test_editAction(self):
        self.test_add()
        self.mt.pt_editAction(REQUEST=self.r,
                              mailhost='MH2',
                              text='new text',
                              content_type='text/fish',
                              expand=1)
        self.assertEqual(self.mt.expand,1)
        self.assertEqual(self.mt.mailhost,'MH2')
        self.assertEqual(self.mt.content_type,'text/fish')
        self.checkContent('new text')

    def test_view_manage_workspace(self):
        self.test_add()
        from zExceptions import Redirect
        try:
            self.assertRaises(self.mt.manage_workspace(self.r))
        except Redirect,r:
            # this may appear to be incorrect, but http://foo/test_mt
            # is what we set as REQUEST['URL1']
            self.assertEqual(r.args,('http://foo/test_mt/pt_editForm',))
        # ugh, okay, so we can't really test for security, but lets
        # test for the missing docstring that was causing problems!
        self.failUnless(self.mt.__doc__)

    def test_view_manage_main(self):
        self.test_add()
        # for some bizare reason the output differs by a newline the first time these are called :-(
        self.mt.manage_main()
        self.mt.pt_editForm()
        self.assertEqual(self.mt.manage_main(),self.mt.pt_editForm())

    # Test Sending
    def testSendSimple(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com', 'to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendSimple.txt')
        self.mt.send(
            mfrom='from@example.com',
            mto=('to@example.com','to2@example.com'),
            mcc=('cc@example.com',),
            mbcc=('bcc@example.com',),
            subject='Hello out there',
            )

        self.MailHost.checkSent()

        # check we're not setting a content type
        self.failIf(self.r.RESPONSE.headers.get('content-type'),
                    self.r.RESPONSE.headers)

    def testMailHostNotAMailHost(self):
        self.test_add('Test Body')
        self.app.MailHost='Hahaha, not a MailHost'
        self.assertRaises(
            RuntimeError,
            self.mt.send,
            mfrom='from@example.com',
            mto=('to@example.com','to2@example.com'),
            mcc=('cc@example.com',),
            mbcc=('bcc@example.com',),
            subject='Hello out there',
            )
        
    def _shouldFail(self,error,**params):        
        self.test_add('Test Body')
        try:
            self.mt.send(**params)
        except TypeError,e:
            self.assertEqual(e.args[0],error)
        else:
            self.fail('Mail sent even though params missing')
        self.MailHost.checkSent(False)

    def testSendMissingParams1(self):
        self._shouldFail(
            'The following parameters were required by not specified: subject',
            mto='to@example.com',
            mfrom='from@example.com'
            )

    def testSendMissingParams2(self):
        self._shouldFail(
            'The following parameters were required by not specified: mfrom',
            mto='to@example.com',
            subject='Test Subject'
            )

    def testSendMissingParams3(self):
        self._shouldFail(
            'The following parameters were required by not specified: mto',
            mfrom='from@example.com',
            subject='Test Subject'
            )

    def testSendMissingParamsAll(self):
        self._shouldFail(
            'The following parameters were required by not specified: mfrom, mto, subject',
            )

    def testSendProperties(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com', 'to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendSimple.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','to@example.com, to2@example.com'),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello out there'),
            ('headers','lines',
             ('Cc:cc@example.com',)),
            ):
            self.mt.manage_addProperty(name,value,type)
            
        self.mt.send()

        self.MailHost.checkSent()
        
    def testSendHeadersDict(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com','to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendHeaders.txt')
        self.mt.send(
            headers = {
            'From':'from@example.com',
            'To':('to@example.com','to2@example.com'),
            'Cc':('cc@example.com',),
            'Bcc':('bcc@example.com',),
            'Subject':'Hello out there',
            'X-Mailer':'MailTemplates',
            }
            )

        self.MailHost.checkSent()
        
    def testSendParametersOverrideHeadersDictOverridesProperties(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com','to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendHeaders2.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','frog@example.com'),
            ('mcc','lines',('cc@example.com',)),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello %s there'),
            ('headers','lines',(
                'X-Mailer: MailTemplates',
                'X-Mailer2: MailTemplatesBad',
                ))
            ):
            self.mt.manage_addProperty(name,value,type)
            
        self.mt.send(subject=self.mt.subject % 'out',
                     headers={
            'To':('to@example.com','to2@example.com'),
            'Subject':'cheese',
            'X-Mailer2':'MailTemplates',
            })

        self.MailHost.checkSent()

    def testSendParametersGoToOptions(self):
        self.test_add('Test <tal:x replace="options/body"/>')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com','to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendSimple.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','frog@example.com'),
            ('mcc','lines',('cc@example.com',)),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello %s there'),
            ):
            self.mt.manage_addProperty(name,value,type)
            
        self.mt.send(subject=self.mt.subject % 'out',
                     headers={
            'To':('to@example.com','to2@example.com'),
            'Subject':'cheese',
            },
                     body='Body')

        self.MailHost.checkSent()

    def testPropertiesParametersAndSubstitution(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com', 'to2@example.com',
                                       'cc@example.com', 'bcc@example.com'),
                                  filename='mail_SendSimple.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','to@example.com, to2@example.com'),
            ('mcc','lines',('cc@example.com',)),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello %s there'),
            ):
            self.mt.manage_addProperty(name,value,type)
            
        self.mt.send(subject=self.mt.subject % 'out')

        self.MailHost.checkSent()
        
    def testGetMessage(self):
        from email.MIMEMultipart import MIMEMultipart
        from email.MIMEText import MIMEText
        
        self.test_add('Test <tal:x replace="options/body"/>')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com','to2@example.com'),
                                  filename='mail_SendAttachment.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','frog@example.com'),
            ('mcc','lines',('cc@example.com',)),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello %s there'),
            ):
            self.mt.manage_addProperty(name,value,type)
            
        msg = self.mt.as_message(subject=self.mt.subject % 'out',
                                 headers={
            'To':('to@example.com','to2@example.com'),
            'Subject':'cheese',
            },
                                 body='Body',
                                 boundary='111',
                                 subtype='alternative')

        self.failUnless(isinstance(msg,MIMEMultipart))
        attachment = MIMEText('A Test Attachment',_subtype='plain')
        attachment.add_header('Content-Disposition', 'attachment', filename='test.txt')
        msg.attach(attachment)
        msg.send()

        self.MailHost.checkSent()

    def _addFileSetup(self):
        from email.MIMEMultipart import MIMEMultipart
        
        self.test_add('Test <tal:x replace="options/body"/>')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com','to2@example.com'),
                                  filename='mail_SendFile.txt')
        for name,type,value in (
            ('mfrom','string','from@example.com'),
            ('mto','string','frog@example.com'),
            ('mcc','lines',('cc@example.com',)),
            ('mbcc','lines',('bcc@example.com',)),
            ('subject','string','Hello %s there'),
            ):
            self.mt.manage_addProperty(name,value,type)
            
        msg = self.mt.as_message(subject=self.mt.subject % 'out',
                                 headers={
            'To':('to@example.com','to2@example.com'),
            'Subject':'cheese',
            },
                                 body='Body',
                                 boundary='111',
                                 subtype='alternative')

        self.failUnless(isinstance(msg,MIMEMultipart))
        return msg
        
    def testZopeFileObject(self):
        self.app.manage_addFile('test.txt',
                                'A Test Attachment')        
        msg = self._addFileSetup()
        msg.add_file(self.app['test.txt'])
        msg.send()
        
        self.MailHost.checkSent()

    def testPythonFileObject(self):
        msg = self._addFileSetup()
        msg.add_file(open(
            os.path.join(test_folder,'test.txt')
            ))
        msg.send()
        
        self.MailHost.checkSent()

    def testFileUploadObject(self):
        msg = self._addFileSetup()
        msg.add_file(self.makeFileUpload(
            value='A Test Attachment'
            ))
        msg.send()
        
        self.MailHost.checkSent()

    def testStringWithContentType(self):
        msg = self._addFileSetup()
        msg.add_file(
            data=open(
            os.path.join(test_folder,'test.txt')
            ).read(),
            filename='test.txt',
            content_type='text/plain'
            )
        msg.send()
        
        self.MailHost.checkSent()

    def testStringWithoutContentType(self):
        msg = self._addFileSetup()
        msg.add_file(
            data=open(
            os.path.join(test_folder,'test.txt')
            ).read(),
            filename='test.txt'
            )
        msg.send()
        
        self.MailHost.checkSent()

    def testTooManyParameters(self):
        msg = self._addFileSetup()
        self.assertRaises(
            TypeError,
            msg.add_file,
            self.makeFileUpload(
            value='A Test Attachment'
            ),
            data=open(
            os.path.join(test_folder,'test.txt')
            ).read(),
            filename='test.txt',
            content_type='text/plain'
            )

    def testTooFewParameters(self):
        msg = self._addFileSetup()
        self.assertRaises(
            TypeError,
            msg.add_file
            )

    def testDataWithoutFilename(self):
        msg = self._addFileSetup()
        self.assertRaises(
            TypeError,
            msg.add_file,
            data=open(
            os.path.join(test_folder,'test.txt')
            ).read(),
            content_type='text/plain'
            )

    def testFilenameWithoutData(self):
        msg = self._addFileSetup()
        self.assertRaises(
            TypeError,
            msg.add_file,
            filename='test.txt',
            content_type='text/plain'
            )

    def testCallAliasesSend(self):
        self.test_add('Test Body')
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com',),
                                  filename='mail_SendSimpleSomeHeaders.txt')
        self.mt(
            mfrom='from@example.com',
            mto=('to@example.com',),
            subject='Test Subject'
            )

        self.MailHost.checkSent()

    def test_encoded_not_html_mode(self):
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com',),
                                  filename='mail_unicode.txt',
                                  payload=u'Test £££\n')
        self.test_add('Test <tal:x replace="options/unicode"/>')
        self.assertEqual(self.mt.content_type,'text/plain')
        self.mt(
            mfrom='from@example.com',
            mto=('to@example.com',),
            subject='Test Subject',
            unicode=u'£££'.encode('utf-8'),
            encoding='utf-8'
            )

    def test_encoded_html_mode(self):
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com',),
                                  filename='mail_unicode2.txt',
                                  payload=u'Test £££')
        self.test_add('')
        self.mt.pt_edit('Test <tal:x replace="options/unicode"/>',
                        'text/html')
        
        self.mt(
            mfrom='from@example.com',
            mto=('to@example.com',),
            subject='Test Subject',
            unicode=u'£££'.encode('utf-8'),
            encoding='utf-8'
            )

    def test_unicode_not_html_mode(self):
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com',),
                                  filename='mail_unicode.txt',
                                  payload=u'Test £££\n')
        self.test_add('Test <tal:x replace="options/unicode"/>')
        self.mt(
            mfrom='from@example.com',
            mto=('to@example.com',),
            subject='Test Subject',
            unicode=u'£££',
            encoding='utf-8'
            )

    def test_unicode_html_mode(self):
        self.MailHost.setExpected(mfrom='from@example.com',
                                  mto=('to@example.com',),
                                  filename='mail_unicode2.txt',
                                  payload=u'Test £££')
        self.test_add('')
        self.mt.pt_edit('Test <tal:x replace="options/unicode"/>',
                        'text/html')

        self.assertEqual(self.mt.content_type,'text/html')
        self.mt(
            mfrom='from@example.com',
            mto=('to@example.com',),
            subject='Test Subject',
            unicode=u'£££',
            encoding='utf-8'
            )

    def test_example1(self):
        # login
        noSecurityManager()
        self.app.aq_chain[-1].id = 'testing'
        newSecurityManager(
            None,
            SimpleUser('Test User','',('Manager',),[]).__of__(self.app)
            )
        try:
            # setup 
            self.r.form['file']=self.makeFileUpload(diskname='example1.mt')
            self.app.manage_addProduct['MailTemplates'].addMailTemplate(
                id='my_mt',
                mailhost='MailHost',
                REQUEST=self.r
                )        
            self.r.form['file']=self.makeFileUpload(diskname='example1.py')
            self.app.manage_addProduct['PythonScripts'].manage_addPythonScript(
                id='test_mt',
                REQUEST=self.r
                )
            # set expected
            self.MailHost.setExpected(mfrom='webmaster@example.com',
                                      mto=('user@example.com',),
                                      filename='example1.txt')
            # test
            self.assertEqual(self.app.test_mt(),'Mail Sent!')
            self.MailHost.checkSent()
        finally:
            # logout
            noSecurityManager()
            newSecurityManager( None, SystemUser )

    def test_example3(self):
        # login
        noSecurityManager()
        self.app.aq_chain[-1].id = 'testing'
        newSecurityManager(
            None,
            SimpleUser('Test User','',('Manager',),[]).__of__(self.app)
            )
        try:
            # setup 
            self.r.form['file']=self.makeFileUpload(diskname='example3.mt')
            self.app.manage_addProduct['MailTemplates'].addMailTemplate(
                id='my_mt',
                mailhost='MailHost',
                REQUEST=self.r
                )        
            self.app.manage_addFile(
                id='myfile.bin',
                file=self.makeFileUpload(diskname='example3.bin')
                )        
            self.r.form['file']=self.makeFileUpload(diskname='example3.py')
            self.app.manage_addProduct['PythonScripts'].manage_addPythonScript(
                id='send_mail',
                REQUEST=self.r
                )
            # set expected
            self.MailHost.setExpected(mfrom='from@example.com',
                                      mto='to1@example.com',
                                      filename='example3.txt')
            # test
            self.assertEqual(self.app.send_mail(),'Mail Sent!')
            self.MailHost.checkSent()
        finally:
            # logout
            noSecurityManager()
            newSecurityManager( None, SystemUser )

    def test_example4(self):
        # login
        noSecurityManager()
        self.app.aq_chain[-1].id = 'testing'
        newSecurityManager(
            None,
            SimpleUser('Test User','',('Manager',),[]).__of__(self.app)
            )
        try:
            # setup 
            self.r.form['file']=self.makeFileUpload(diskname='example4.mt')
            self.app.manage_addProduct['MailTemplates'].addMailTemplate(
                id='my_mt',
                mailhost='MailHost',
                REQUEST=self.r
                )
            self.app.my_mt.manage_addProperty(
                'subject','Welcome to %s','string'
                )
            self.app.my_mt.manage_addProperty(
                'mfrom','webmaster@example.com','string'
                )
            self.r.form['file']=self.makeFileUpload(diskname='example4.py')
            self.app.manage_addProduct['PythonScripts'].manage_addPythonScript(
                id='send_mail',
                REQUEST=self.r
                )
            # set expected
            self.MailHost.setExpected(mfrom='webmaster@example.com',
                                      mto=('user@example.com',),
                                      filename='example4.txt')
            # test
            self.assertEqual(self.app.send_mail(),'Mail Sent!')
            self.MailHost.checkSent()
        finally:
            # logout
            noSecurityManager()
            newSecurityManager( None, SystemUser )

def test_suite():
    return TestSuite((
        makeSuite(TestMailTemplate),
        ))

if __name__ == '__main__':
    main(defaultTest='test_suite')




msg = container.my_mt.as_message(
    mfrom='from@example.com',
    mto='to1@example.com',
    subject='Your requested file',
    boundary='111' # for testing only, so we get a consistent boundary
    )
msg.add_file(container['myfile.bin'])
msg.send()
return 'Mail Sent!'



# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

from AccessControl import ClassSecurityInfo
from AccessControl import getSecurityManager
from App.class_init import InitializeClass
from Products.CMFCore.FSPageTemplate import FSPageTemplate,expandpath
from Products.CMFCore.DirectoryView import registerFileExtension
from Products.CMFCore.DirectoryView import registerMetaType

from BaseMailTemplate import BaseMailTemplate
from MailTemplate import MailTemplate

class FSMailTemplate(BaseMailTemplate,FSPageTemplate):
    "Wrapper for Mail Template"
    
    security = ClassSecurityInfo()

    meta_type = 'Filesystem Mail Template'

    def __init__(self, id, filepath, fullname=None, properties=None):
        FSPageTemplate.__init__(self,id,filepath,fullname,properties)
        self._properties = properties

    security.declarePrivate('_createZODBClone')
    def _createZODBClone(self):
        """Create a ZODB (editable) equivalent of this object."""
        obj = MailTemplate(self.getId(), self._text, self.content_type)
        obj.expand = 0
        obj.write(self.read())
        obj._setPropValue('mailhost',self.mailhost)
        obj.content_type = self.content_type
        if self._properties:
            keys = self._properties.keys()
            keys.sort()
            for id in keys:
                if id not in ('mailhost','content_type'):
                    obj.manage_addProperty(id,self._properties[id],'string')
        return obj

    security.declarePrivate('_readFile')
    def _readFile(self, reparse):
        fp = expandpath(self._filepath)
        file = open(fp, 'r')    # not 'rb', as this is a text file!
        try:
            data = file.read()
        finally:
            file.close()
        if reparse:
            self.write(data)

    def _exec(self, bound_names, args, kw):
        """Call a FSPageTemplate"""
        try:
            response = self.REQUEST.RESPONSE
        except AttributeError:
            response = None
        # Read file first to get a correct content_type default value.
        self._updateFromFS()

        if not kw.has_key('args'):
            kw['args'] = args
        bound_names['options'] = kw

        security=getSecurityManager()
        bound_names['user'] = security.getUser()

        # Retrieve the value from the cache.
        keyset = None
        if self.ZCacheable_isCachingEnabled():
            # Prepare a cache key.
            keyset = {
                      # Why oh why?
                      # All this code is cut and paste
                      # here to make sure that we
                      # dont call _getContext and hence can't cache
                      # Annoying huh?
                      'here': self.aq_parent.getPhysicalPath(),
                      'bound_names': bound_names}
            result = self.ZCacheable_get(keywords=keyset)
            if result is not None:
                # Got a cached value.
                return result

        # Execute the template in a new security context.
        security.addContext(self)
        try:
            result = self.pt_render(extra_context=bound_names)
            if keyset is not None:
                # Store the result in the cache.
                self.ZCacheable_set(result, keywords=keyset)
            return result
        finally:
            security.removeContext(self)

        return result

InitializeClass(FSMailTemplate)

registerFileExtension('mt', FSMailTemplate)
registerMetaType('Mail Template', FSMailTemplate)



# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

from AccessControl import allow_module,allow_class
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.PageTemplates.PageTemplateFile import guess_type
from MailTemplate import MailTemplate
from types import ClassType
from urllib import quote

try:
    import Products.CMFCore
except ImportError:
    pass
else:
    import FSMailTemplate
    import Products.CMFCore.utils
    Products.CMFCore.utils.registerIcon(FSMailTemplate.FSMailTemplate,
                                        'www/fsmt.gif', globals())

def initialize( context ):
    context.registerClass(
        MailTemplate,
        # we use the same permission as page templates
        # in order to keep things simple.
        permission='Add Page Templates',
        constructors=(addMailTemplateForm,
                      addMailTemplate),
        icon='www/mt.gif',
        )

addMailTemplateForm = PageTemplateFile(
    'www/mtAdd',
    globals(),
    __name__='addMailTemplateForm'
    )
def addMailTemplate(self, id, mailhost=None, text='', encoding='utf-8',
                    REQUEST=None, submit=None):
    "Add a Mail Template with optional file content."

    filename = ''
    content_type = 'text/html'

    if REQUEST and REQUEST.has_key('file'):
        file = REQUEST['file']
        filename = file.filename
        text = file.read()
        headers = getattr(file, 'headers', None)
        if headers and headers.has_key('content_type'):
            content_type = headers['content_type']
        else:
            content_type = guess_type(filename, text) 


    else:
        if hasattr(text, 'read'):
            filename = getattr(text, 'filename', '')
            headers = getattr(text, 'headers', None)
            text = text.read()
            if headers and headers.has_key('content_type'):
                content_type = headers['content_type']
            else:
                content_type = guess_type(filename, text) 

    # ensure that we pass unicode to the constructor to
    # avoid further hassles with pt_edit()

    if not isinstance(text, unicode):
        text = unicode(text, encoding)

    mt = MailTemplate(id, text, content_type, output_encoding=encoding)
    self._setObject(id, mt)
    ob = getattr(self, id)
    if mailhost:
        ob._setPropValue('mailhost',mailhost)

    if REQUEST is not None:
        if submit == " Add and Edit ":
            u = ob.absolute_url()
        else:
            u = ob.aq_parent.absolute_url()
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    else:
        return ob

# allow all the email module's public bits
import email
for name in email.__all__:
    path = 'email.'+name
    allow_module(path)
    try:
        mod = __import__(path)
    except ImportError:
        pass
    else:
        mod = getattr(mod,name)
        for mod_name in dir(mod):
            obj = getattr(mod,mod_name)
            if isinstance(obj,ClassType):
                allow_class(obj)
    



# Copyright (c) 2005-2010 Simplistix Ltd
# See license.txt for license details.

import os
from setuptools import setup,find_packages

package_name = 'Products.MailTemplates'
base_dir = os.path.dirname(__file__)

setup(
    name=package_name,
    version='2.0.0',
    author='Chris Withers',
    author_email='chris@simplistix.co.uk',
    license='MIT',
    description="MailTemplates for Zope 2",
    long_description=open(os.path.join(base_dir,'docs','description.txt')).read(),
    url='http://www.simplistix.co.uk/software/zope/mailtemplates',
    classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    ],    
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires = (
        'Zope2',
        ),
    )



# Copyright (c) 2005-2010 Simplistix Ltd
#
# This Software is released under the MIT License:
# http://www.opensource.org/licenses/mit-license.html
# See license.txt for more details.

from AccessControl import ClassSecurityInfo
from email import Encoders
from email.MIMEBase import MIMEBase
from email.MIMEMultipart import MIMEMultipart
from App.class_init import InitializeClass
from zope.contenttype import guess_content_type
from OFS.Image import File
from ZPublisher.HTTPRequest import FileUpload

def cookId(filename):
    return filename[max(filename.rfind('/'),
                        filename.rfind('\\'),
                        filename.rfind(':'),
                        )+1:]
    
class MTMultipart(MIMEMultipart):

    security = ClassSecurityInfo()
    
    security.setDefaultAccess('allow')
    
    def __init__(self,mt,mfrom,mto,_subtype='mixed',boundary=None):
        MIMEMultipart.__init__(self,_subtype,boundary)
        self.mfrom = mfrom
        self.mto = mto
        self.mt = mt

    security.declarePublic('send')
    def send(self):
        "send ourselves using our MailTemplate's send method"
        return self.mt._send(self.mfrom,self.mto,self)

    security.declarePublic('add_file')
    def add_file(self,theFile=None,data=None,filename=None,content_type=None):
        "add a Zope file or Image to ourselves as an attachment"
        if theFile and data:
            raise TypeError(
                'A file-like object was passed as well as data to create a file'
                )
        if (data or filename) and not (data and filename):
            raise TypeError(
                'Both data and filename must be specified'
                )
        if data:
            if content_type is None:
                content_type, enc=guess_content_type(filename, data)
        elif isinstance(theFile,File):
            filename = theFile.getId()
            data = str(theFile.data)
            content_type = content_type or theFile.content_type
        elif isinstance(theFile,file):
            filename = cookId(theFile.name)
            data = theFile.read()
            if content_type is None:
                content_type,enc = guess_content_type(filename, data)
        elif isinstance(theFile,FileUpload):
            filename = cookId(theFile.filename)
            data=theFile.read()
            headers=theFile.headers
            if content_type is None:
                if headers.has_key('content-type'):
                    content_type=headers['content-type']
                else:
                    content_type, enc=guess_content_type(filename, data)
        else:
            raise TypeError('Unknown object type found: %r' % theFile)
        
        msg = MIMEBase(*content_type.split('/'))
        msg.set_payload(data)
        Encoders.encode_base64(msg)
        msg.add_header('Content-Disposition', 'attachment',
                       filename=filename)
        self.attach(msg)
        
InitializeClass(MTMultipart)
